@@ -29,17 +29,37 @@ class ValidationStepSchema(Schema):
     validators = fields.Nested(ValidatorSchema, many=True)
 
 
+class ValidatorResultSchema(Schema):
+
+    value = fields.Raw()
+    passed = fields.Boolean()
+    validator = fields.Nested(ValidatorSchema, many=False)
+
+
+class ValidationErrorSchema(Schema):
+
+    message = fields.String()
+    validator = fields.Nested(ValidatorSchema, many=False)
+    processor = fields.Nested(
+        ProcessorSchema,
+        many=False,
+    )
+
+
 class ValidationResultSchema(Schema):
 
     """Serialized validation result"""
 
     filepath = fields.String()
-    results = fields.List(
-        fields.Tuple(
-            (
-                fields.Raw(),
-                fields.Bool(),
-            )
-        )
+    processor = fields.Nested(
+        ProcessorSchema,
+        many=False,
+    )
+    results = fields.Nested(
+        ValidatorResultSchema,
+        many=True,
+    )
+    errors = fields.Nested(
+        ValidationErrorSchema,
+        many=True,
     )
-    errors = fields.List(fields.String())
